==> s3-0.26.0-sources.jar: software/amazon/awscdk/services/s3/BucketPolicyProps.java <==
package software.amazon.awscdk.services.s3;

@javax.annotation.Generated(value = "jsii-pacmak/0.7.15 (build e429c41)", date = "2019-03-20T12:58:45.911Z")
public interface BucketPolicyProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * The Amazon S3 bucket that the policy applies to.
     */
    software.amazon.awscdk.services.s3.IBucket getBucket();
    /**
     * The Amazon S3 bucket that the policy applies to.
     */
    void setBucket(final software.amazon.awscdk.services.s3.IBucket value);

    /**
     * @return a {@link Builder} of {@link BucketPolicyProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link BucketPolicyProps}
     */
    final class Builder {
        private software.amazon.awscdk.services.s3.IBucket _bucket;

        /**
         * Sets the value of Bucket
         * @param value The Amazon S3 bucket that the policy applies to.
         * @return {@code this}
         */
        public Builder withBucket(final software.amazon.awscdk.services.s3.IBucket value) {
            this._bucket = java.util.Objects.requireNonNull(value, "bucket is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BucketPolicyProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public BucketPolicyProps build() {
            return new BucketPolicyProps() {
                private software.amazon.awscdk.services.s3.IBucket $bucket = java.util.Objects.requireNonNull(_bucket, "bucket is required");

                @Override
                public software.amazon.awscdk.services.s3.IBucket getBucket() {
                    return this.$bucket;
                }

                @Override
                public void setBucket(final software.amazon.awscdk.services.s3.IBucket value) {
                    this.$bucket = java.util.Objects.requireNonNull(value, "bucket is required");
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.s3.BucketPolicyProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The Amazon S3 bucket that the policy applies to.
         */
        @Override
        public software.amazon.awscdk.services.s3.IBucket getBucket() {
            return this.jsiiGet("bucket", software.amazon.awscdk.services.s3.IBucket.class);
        }

        /**
         * The Amazon S3 bucket that the policy applies to.
         */
        @Override
        public void setBucket(final software.amazon.awscdk.services.s3.IBucket value) {
            this.jsiiSet("bucket", java.util.Objects.requireNonNull(value, "bucket is required"));
        }
    }
}

==> s3-0.27.0-sources.jar: software/amazon/awscdk/services/s3/BucketPolicyProps.java <==
package software.amazon.awscdk.services.s3;

@javax.annotation.Generated(value = "jsii-pacmak/0.8.2 (build e9eb3c9)", date = "2019-03-28T21:36:36.826Z")
public interface BucketPolicyProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * The Amazon S3 bucket that the policy applies to.
     */
    software.amazon.awscdk.services.s3.IBucket getBucket();

    /**
     * @return a {@link Builder} of {@link BucketPolicyProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link BucketPolicyProps}
     */
    final class Builder {
        private software.amazon.awscdk.services.s3.IBucket _bucket;

        /**
         * Sets the value of Bucket
         * @param value The Amazon S3 bucket that the policy applies to.
         * @return {@code this}
         */
        public Builder withBucket(final software.amazon.awscdk.services.s3.IBucket value) {
            this._bucket = java.util.Objects.requireNonNull(value, "bucket is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BucketPolicyProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public BucketPolicyProps build() {
            return new BucketPolicyProps() {
                private final software.amazon.awscdk.services.s3.IBucket $bucket = java.util.Objects.requireNonNull(_bucket, "bucket is required");

                @Override
                public software.amazon.awscdk.services.s3.IBucket getBucket() {
                    return this.$bucket;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("bucket", om.valueToTree(this.getBucket()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.s3.BucketPolicyProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The Amazon S3 bucket that the policy applies to.
         */
        @Override
        public software.amazon.awscdk.services.s3.IBucket getBucket() {
            return this.jsiiGet("bucket", software.amazon.awscdk.services.s3.IBucket.class);
        }
    }
}
